@@ -35,9 +35,9 @@ class AsyncModbusSerialClient(ModbusBaseClient):
     :param stopbits: Number of stop bits 1, 1.5, 2.
     :param handle_local_echo: Discard local echo from dongle.
     :param name: Set communication name, used in logging
-    :param reconnect_delay: Minimum delay in seconds.milliseconds before reconnecting.
-    :param reconnect_delay_max: Maximum delay in seconds.milliseconds before reconnecting.
-    :param timeout: Timeout for connecting and receiving data, in seconds.
+    :param reconnect_delay: Minimum delay when reconnecting, in seconds (use decimals for milliseconds).
+    :param reconnect_delay_max: Maximum delay when reconnecting, in seconds (use decimals for milliseconds).
+    :param timeout: Timeout for connecting and receiving data, in seconds (use decimals for milliseconds).
     :param retries: Max number of retries per request.
     :param trace_packet: Called with bytestream received/to be sent
     :param trace_pdu: Called with PDU received/to be sent
@@ -270,7 +270,7 @@ class ModbusSerialClient(ModbusBaseSyncClient):
             if waitingbytes := self._in_waiting():
                 result = self.socket.read(waitingbytes)
                 Log.warning("Cleanup recv buffer before send: {}", result, ":hex")
-            if (size := self.socket.write(request)) is None:
+            if (size := self.socket.write(request)) is None:  # pragma: no cover
                 size = 0
             return size
         return 0
