@@ -29,47 +29,27 @@ class ModbusStatus(int, enum.Enum):
     .. attribute:: OFF
 
        This indicates that the given modbus entity is off
-
-    .. attribute:: SLAVE_ON
-
-       This indicates that the given modbus slave is running
-
-    .. attribute:: SLAVE_OFF
-
-       This indicates that the given modbus slave is not running
     """
 
     WAITING = 0xFFFF
     READY = 0x0000
     ON = 0xFF00
     OFF = 0x0000
-    SLAVE_ON = 0xFF
-    SLAVE_OFF = 0x00
 
 
-class Endian(str, enum.Enum):
-    """An enumeration representing the various byte endianness.
+class ExcCodes(int, enum.Enum):
+   """Represents the allowed exception codes."""
 
-    .. attribute:: AUTO
-
-       This indicates that the byte order is chosen by the
-       current native environment.
-
-    .. attribute:: BIG
-
-       This indicates that the bytes are in big endian format
-
-    .. attribute:: LITTLE
-
-       This indicates that the bytes are in little endian format
-
-    .. note:: I am simply borrowing the format strings from the
-       python struct module for my convenience.
-    """
-
-    AUTO = "@"
-    BIG = ">"
-    LITTLE = "<"
+   ILLEGAL_FUNCTION = 0x01
+   ILLEGAL_ADDRESS = 0x02
+   ILLEGAL_VALUE = 0x03
+   DEVICE_FAILURE = 0x04
+   ACKNOWLEDGE = 0x05
+   DEVICE_BUSY = 0x06
+   NEGATIVE_ACKNOWLEDGE = 0x07
+   MEMORY_PARITY_ERROR = 0x08
+   GATEWAY_PATH_UNAVIABLE = 0x0A
+   GATEWAY_NO_RESPONSE = 0x0B
 
 
 class ModbusPlusOperation(int, enum.Enum):
@@ -122,10 +102,6 @@ class DeviceInformation(int, enum.Enum):
     EXTENDED = 0x03
     SPECIFIC = 0x04
 
-    def __str__(self):
-        """Override to force int representation for enum members."""
-        return str(int(self))
-
 
 class MoreData(int, enum.Enum):
     """Represents the more follows condition.
@@ -141,4 +117,3 @@ class MoreData(int, enum.Enum):
 
     NOTHING = 0x00
     KEEP_READING = 0xFF
-
