@@ -1,59 +1,51 @@
 """Remote datastore."""
-from pymodbus.datastore import ModbusBaseSlaveContext
 from pymodbus.exceptions import NotImplementedException
-from pymodbus.logging import Log
+from pymodbus.pdu import ExceptionResponse
+
+from .context import ModbusBaseDeviceContext
 
 
 # ---------------------------------------------------------------------------#
 #  Context
 # ---------------------------------------------------------------------------#
-class RemoteSlaveContext(ModbusBaseSlaveContext):
+class RemoteDeviceContext(ModbusBaseDeviceContext):
     """TODO.
 
     This creates a modbus data model that connects to
     a remote device (depending on the client used)
     """
 
-    def __init__(self, client, slave=None):
+    def __init__(self, client, device_id=None):
         """Initialize the datastores.
 
         :param client: The client to retrieve values with
-        :param slave: Unit ID of the remote slave
+        :param device_id: Unit ID of the remote device
         """
         self._client = client
-        self.slave = slave
+        self.device_id = device_id
         self.result = None
         self.__build_mapping()
-        if not self.__set_callbacks:
-            Log.error("Init went wrong.")
 
     def reset(self):
         """Reset all the datastores to their default values."""
         raise NotImplementedException()
 
-    def validate(self, _fc_as_hex, _address, _count):
-        """Validate the request to make sure it is in range.
-
-        :returns: True
-        """
-        return True
-
-    def getValues(self, fc_as_hex, _address, _count=1):
-        """Get values from real call in validate."""
-        if fc_as_hex in self._write_fc:
+    def getValues(self, func_code, address, count=1):
+        """Get values from remote device."""
+        if func_code in self._write_fc:
             return [0]
-        group_fx = self.decode(fc_as_hex)
+        group_fx = self.decode(func_code)
         func_fc = self.__get_callbacks[group_fx]
-        self.result = func_fc(_address, _count)
-        return self.__extract_result(self.decode(fc_as_hex), self.result)
+        self.result = func_fc(address, count)
+        return self.__extract_result(self.decode(func_code), self.result)
 
-    def setValues(self, fc_as_hex, address, values):
+    def setValues(self, func_code, address, values):
         """Set the datastore with the supplied values."""
-        group_fx = self.decode(fc_as_hex)
-        if fc_as_hex not in self._write_fc:
-            raise ValueError(f"setValues() called with an non-write function code {fc_as_hex}")
-        func_fc = self.__set_callbacks[f"{group_fx}{fc_as_hex}"]
-        if fc_as_hex in {0x0F, 0x10}:  # Write Multiple Coils, Write Multiple Registers
+        group_fx = self.decode(func_code)
+        if func_code not in self._write_fc:
+            raise ValueError(f"setValues() called with an non-write function code {func_code}")
+        func_fc = self.__set_callbacks[f"{group_fx}{func_code}"]
+        if func_code in {0x0F, 0x10}:  # Write Multiple Coils, Write Multiple Registers
             self.result = func_fc(address, values)
         else:
             self.result = func_fc(address, values[0])
@@ -65,13 +57,13 @@ class RemoteSlaveContext(ModbusBaseSlaveContext):
 
         :returns: A string representation of the context
         """
-        return f"Remote Slave Context({self._client})"
+        return f"Remote Device Context({self._client})"
 
     def __build_mapping(self):
         """Build the function code mapper."""
         params = {}
-        if self.slave:
-            params["slave"] = self.slave
+        if self.device_id:
+            params["device_id"] = self.device_id
         self.__get_callbacks = {
             "d": lambda a, c: self._client.read_discrete_inputs(
                 a, count=c, **params
@@ -85,6 +77,8 @@ class RemoteSlaveContext(ModbusBaseSlaveContext):
             "i": lambda a, c: self._client.read_input_registers(
                 a, count=c, **params
             ),
+            "x": lambda a, c: ExceptionResponse(0
+            ),
         }
         self.__set_callbacks = {
             "d5": lambda a, v: self._client.write_coil(
@@ -114,16 +108,15 @@ class RemoteSlaveContext(ModbusBaseSlaveContext):
         }
         self._write_fc = (0x05, 0x06, 0x0F, 0x10)
 
-    def __extract_result(self, fc_as_hex, result):
+    def __extract_result(self, func_code, result):
         """Extract the values out of a response.
 
         TODO make this consistent (values?)
         """
-        if not result.isError():
-            if fc_as_hex in {"d", "c"}:
-                return result.bits
-            if fc_as_hex in {"h", "i"}:
-                return result.registers
-        else:
-            return result
-        return None
+        if result.isError():
+            return None
+        if func_code in {"d", "c"}:
+            return result.bits
+        if func_code in {"h", "i"}:
+            return result.registers
+        return result
