@@ -8,7 +8,9 @@ from collections.abc import Callable
 from datetime import datetime
 from typing import Any
 
-from pymodbus.datastore.context import ModbusBaseSlaveContext
+from pymodbus.constants import ExcCodes
+
+from .context import ModbusBaseDeviceContext
 
 
 WORD_SIZE = 16
@@ -219,7 +221,7 @@ class Setup:
     def handle_setup_section(self):
         """Load setup section."""
         layout = Label.try_get(Label.setup, self.config)
-        self.runtime.fc_offset = {key: 0 for key in range(25)}
+        self.runtime.fc_offset = dict.fromkeys(range(25), 0)
         size_co = Label.try_get(Label.co_size, layout)
         size_di = Label.try_get(Label.di_size, layout)
         size_hr = Label.try_get(Label.hr_size, layout)
@@ -339,15 +341,15 @@ class Setup:
         }
         if custom_actions:
             actions.update(custom_actions)
-        self.runtime.action_name_to_id = {None: 0}
+
         self.runtime.action_id_to_name = [Label.none]
         self.runtime.action_methods = [None]
-        i = 1
-        for key, method in actions.items():
+        for i, (key, method) in enumerate(actions.items(), start=1):
             self.runtime.action_name_to_id[key] = i
             self.runtime.action_id_to_name.append(key)
             self.runtime.action_methods.append(method)
-            i += 1
+        self.runtime.action_name_to_id.update({None: 0})
+
         self.runtime.registerType_name_to_id = {
             Label.type_bits: CellType.BITS,
             Label.type_uint16: CellType.UINT16,
@@ -357,11 +359,15 @@ class Setup:
             Label.next: CellType.NEXT,
             Label.invalid: CellType.INVALID,
         }
-        self.runtime.registerType_id_to_name = [None] * len(
-            self.runtime.registerType_name_to_id
-        )
-        for name, cell_type in self.runtime.registerType_name_to_id.items():
-            self.runtime.registerType_id_to_name[cell_type] = name
+        self.runtime.registerType_id_to_name = [
+            "invalid",    # 0
+            "bits",       # 1
+            "uint16",     # 2
+            "uint32",     # 3
+            "float32",    # 4
+            "string",     # 5
+            "next",       # 6
+        ]
 
         self.config = config
         self.handle_setup_section()
@@ -373,7 +379,7 @@ class Setup:
             raise RuntimeError(f"INVALID key in setup: {self.config}")
 
 
-class ModbusSimulatorContext(ModbusBaseSlaveContext):
+class ModbusSimulatorContext(ModbusBaseDeviceContext):
     """Modbus simulator.
 
     :param config: A dict with structure as shown below.
@@ -481,7 +487,8 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
         self.action_methods: list[Callable] = []
         self.registerType_name_to_id: dict[str, int] = {}
         self.registerType_id_to_name: list[str] = []
-        Setup(self).setup(config, custom_actions)
+        if config:
+            Setup(self).setup(config, custom_actions)
 
     # --------------------------------------------
     # Simulator server interface
@@ -560,6 +567,8 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
                 while i < end_address:
                     if self.registers[i].type == CellType.NEXT:
                         i += 1
+                    else:
+                        return False
         return True
 
     def validate(self, func_code, address, count=1):
@@ -579,11 +588,13 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
         fx_write = func_code in self._write_func_code
         return self.loop_validate(real_address, real_address + count, fx_write)
 
-    def getValues(self, func_code, address, count=1):
+    def getValues(self, func_code, address, count=1) -> list[int] | list[bool] | ExcCodes:
         """Return the requested values of the datastore.
 
         :meta private:
         """
+        if not self.validate(func_code, address, count):
+            return ExcCodes.ILLEGAL_ADDRESS
         result = []
         if func_code not in self._bits_func_code:
             real_address = self.fc_offset[func_code] + address
@@ -614,7 +625,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
                 bit_index = 0
         return result
 
-    def setValues(self, func_code, address, values):
+    def setValues(self, func_code, address, values) -> None | ExcCodes:
         """Set the requested values of the datastore.
 
         :meta private:
@@ -622,15 +633,20 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
         if func_code not in self._bits_func_code:
             real_address = self.fc_offset[func_code] + address
             for value in values:
+                if not self.validate(func_code, address):
+                    return ExcCodes.ILLEGAL_ADDRESS
                 self.registers[real_address].value = value
                 self.registers[real_address].count_write += 1
                 real_address += 1
-            return
+                address += 1
+            return None
 
         # bit access
         real_address = self.fc_offset[func_code] + int(address / 16)
         bit_index = address % 16
         for value in values:
+            if not self.validate(func_code, address):
+                return ExcCodes.ILLEGAL_ADDRESS
             bit_mask = 2**bit_index
             if bool(value):
                 self.registers[real_address].value |= bit_mask
@@ -641,7 +657,8 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
             if bit_index == 16:
                 bit_index = 0
                 real_address += 1
-        return
+                address += 1
+        return None
 
     # --------------------------------------------
     # Internal action methods
@@ -694,7 +711,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
             new_regs = cls.build_registers_from_value(value, False)
             reg.value = new_regs[0]
             reg2.value = new_regs[1]
-        elif cell.type == CellType.UINT32:
+        else: # if cell.type == CellType.UINT32:
             tmp_reg = [reg.value, reg2.value]
             value = cls.build_value_from_registers(tmp_reg, True)
             value += 1
@@ -743,7 +760,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
             regs = cls.build_registers_from_value(value, False)
             registers[inx].value = regs[0]
             registers[inx + 1].value = regs[1]
-        elif cell.type == CellType.UINT32:
+        else: # if cell.type == CellType.UINT32:
             regs = cls.build_registers_from_value(value, True)
             registers[inx].value = regs[0]
             registers[inx + 1].value = regs[1]
@@ -752,32 +769,6 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
     # Internal helper methods
     # --------------------------------------------
 
-    def validate_type(self, func_code, real_address, count) -> bool:
-        """Check if request is done against correct type.
-
-        :meta private:
-        """
-        check: tuple
-        if func_code in self._bits_func_code:
-            # Bit access
-            check = (CellType.BITS, -1)
-            reg_step = 1
-        elif count % 2:
-            # 16 bit access
-            check = (CellType.UINT16, CellType.STRING)
-            reg_step = 1
-        else:
-            check = (CellType.UINT32, CellType.FLOAT32, CellType.STRING)
-            reg_step = 2
-
-        for i in range(real_address, real_address + count, reg_step):
-            if self.registers[i].type in check:
-                continue
-            if self.registers[i].type is CellType.NEXT:
-                continue
-            return False
-        return True
-
     @classmethod
     def build_registers_from_value(cls, value, is_int):
         """Build registers from int32 or float32."""
