@@ -5,10 +5,9 @@ Custom exceptions to be used in the Modbus code.
 
 __all__ = [
     "ConnectionException",
-    "InvalidMessageReceivedException",
     "MessageRegisterException",
     "ModbusIOException",
-    "NoSuchSlaveException",
+    "NoSuchIdException",
     "NotImplementedException",
     "ParameterException",
 ]
@@ -59,15 +58,15 @@ class ParameterException(ModbusException):
         ModbusException.__init__(self, message)
 
 
-class NoSuchSlaveException(ModbusException):
-    """Error resulting from making a request to a slave that does not exist."""
+class NoSuchIdException(ModbusException):
+    """Error resulting from making a request to a id that does not exist."""
 
     def __init__(self, string=""):
         """Initialize the exception.
 
         :param string: The message to append to the error
         """
-        message = f"[No Such Slave] {string}"
+        message = f"[No Such id] {string}"
         ModbusException.__init__(self, message)
 
 
@@ -95,18 +94,6 @@ class ConnectionException(ModbusException):
         ModbusException.__init__(self, message)
 
 
-class InvalidMessageReceivedException(ModbusException):
-    """Error resulting from invalid response received or decoded."""
-
-    def __init__(self, string=""):
-        """Initialize the exception.
-
-        :param string: The message to append to the error
-        """
-        message = f"[Invalid Message] {string}"
-        ModbusException.__init__(self, message)
-
-
 class MessageRegisterException(ModbusException):
     """Error resulting from failing to register a custom message request/response."""
 
