@@ -19,18 +19,18 @@ class FramerTLS(FramerBase):
     MIN_SIZE = 8
 
     def decode(self, data: bytes) -> tuple[int, int, int, bytes]:
-        """Decode MDAP+PDU."""
+        """Decode MDAP+payload."""
         tid = int.from_bytes(data[0:2], 'big')
         dev_id = int(data[6])
         return len(data), dev_id, tid, data[7:]
 
-    def encode(self, pdu: bytes, device_id: int, tid: int) -> bytes:
-        """Encode MDAP+PDU."""
+    def encode(self, payload: bytes, device_id: int, tid: int) -> bytes:
+        """Encode MDAP+payload."""
         frame = (
            tid.to_bytes(2, 'big') +
            b'\x00\x00' +
-           (len(pdu) + 1).to_bytes(2, 'big') +
+           (len(payload) + 1).to_bytes(2, 'big') +
            device_id.to_bytes(1, 'big') +
-           pdu
+           payload
         )
         return frame
